@@ -178,8 +178,9 @@ namespace mfront {
     //
     this->registerCallBack(
         "--modelling-hypothesis",
-        CallBack("select a modelling hypothesis",
-                 [this] { this->treatModellingHypothesis(); }, true));
+        CallBack(
+            "select a modelling hypothesis",
+            [this] { this->treatModellingHypothesis(); }, true));
     // standard queries
     const std::vector<std::pair<const char*, const char*>> sq = {
         {"--behaviour-name", "show the behaviour name"},
@@ -585,14 +586,12 @@ namespace mfront {
                             "no slip system defined");
              const auto& ssd = d.getSlipSystems();
              const auto nss = ssd.getNumberOfSlipSystemsFamilies();
-             auto r = size_t{};
              for (size_t i = 0; i != nss; ++i) {
                const auto os = ssd.getOrientationTensors(i);
                const auto ss = ssd.getSlipSystems(i);
                for (decltype(ss.size()) j = 0; j != ss.size(); ++j) {
                  cout << "- " << to_string(ss[j]) << ": " << to_string(os[j])
                       << '\n';
-                 ++r;
                }
              }
            }});
@@ -639,14 +638,12 @@ namespace mfront {
                             "no slip system defined");
              const auto& ssd = d.getSlipSystems();
              const auto nss = ssd.getNumberOfSlipSystemsFamilies();
-             auto r = size_t{};
              for (size_t i = 0; i != nss; ++i) {
                const auto os = ssd.getClimbTensors(i);
                const auto ss = ssd.getSlipSystems(i);
                for (decltype(ss.size()) j = 0; j != ss.size(); ++j) {
                  cout << "- " << to_string(ss[j]) << ": " << to_string(os[j])
                       << '\n';
-                 ++r;
                }
              }
            }});
