@@ -693,6 +693,16 @@ namespace mfront {
         return "(" + var + "+(this->theta)*d" + var + ")";
       }
     }
+    if (d.isAuxiliaryStateVariableName(var)){
+      const auto& v = d.getAuxiliaryStateVariables().getVariable(var);
+      if (v.getAttribute<bool>("ComputedByExternalModel", false)) {
+        if (addThisPtr) {
+          return "(this->" + var + "+(this->theta)*(this->d" + var + "))";
+        } else {
+          return "(" + var + "+(this->theta)*d" + var + ")";
+        }
+      }
+    }
     if (d.isIntegrationVariableName(var)) {
       if (this->mb.hasAttribute(h, var + "_normalisation_factor")) {
         const auto& nf = this->mb.getAttribute<std::string>(
@@ -733,6 +743,16 @@ namespace mfront {
         return "(" + var + "+d" + var + ")";
       }
     }
+    if (d.isAuxiliaryStateVariableName(var)){
+      const auto& v = d.getAuxiliaryStateVariables().getVariable(var);
+      if (v.getAttribute<bool>("ComputedByExternalModel", false)){
+        if (addThisPtr) {
+          return "(this->" + var + "+this->d" + var + ")";
+        } else {
+          return "(" + var + "+d" + var + ")";
+        }
+      }
+    }
     if ((d.isExternalStateVariableIncrementName(var)) || (var == "dT")) {
       this->mb
           .declareExternalStateVariableProbablyUnusableInPurelyImplicitResolution(
