@@ -30,7 +30,7 @@
 #include <io.h>
 #define F_OK 0 /* Test for existence.  */
 #ifndef S_ISREG
-#define S_ISREG(mode) (((mode)&S_IFMT) == S_IFREG)
+#define S_ISREG(mode) (((mode) & S_IFMT) == S_IFREG)
 #endif
 #endif
 
@@ -365,7 +365,8 @@ namespace mfront {
     writeInterfaceSymbol(srcFile, name, "Python");
     writeLawSymbol(srcFile, name, mpd.material);
     writeMaterialSymbol(srcFile, name, mpd.material);
-    writeMaterialKnowledgeTypeSymbol(srcFile, name, MATERIALPROPERTY);
+    writeMaterialKnowledgeTypeSymbol(srcFile, name,
+                                     MaterialKnowledgeType::MATERIALPROPERTY);
     writeParametersSymbols(srcFile, name, mpd);
     // parameters
     if ((!areParametersTreatedAsStaticVariables(mpd)) &&
@@ -376,7 +377,7 @@ namespace mfront {
               << "const double v"
               << "){\n";
       for (const auto& p : mpd.parameters) {
-        srcFile << "if(strcmp(\"" << p.name << "\",p)==0){\n"
+        srcFile << "if(strcmp(\"" << p.name << "\",p) == 0){\n"
                 << "python::" << hn << "::get" << hn << "()." << p.name
                 << " = v;\n"
                 << "return 1;\n"
@@ -436,21 +437,23 @@ namespace mfront {
       }
       srcFile << ")){\nreturn NULL;\n}\n";
     }
-    if ((hasPhysicalBounds(mpd.inputs)) || (hasBounds(mpd.inputs))) {
-      srcFile << "#ifndef PYTHON_NO_BOUNDS_CHECK\n";
-      if (hasPhysicalBounds(mpd.inputs)) {
-        srcFile << "// treating physical bounds\n";
-        for (const auto& i : mpd.inputs) {
-          writePhysicalBounds(srcFile, name, i);
+    if (!areRuntimeChecksDisabled(mpd)) {
+      if ((hasPhysicalBounds(mpd.inputs)) || (hasBounds(mpd.inputs))) {
+        srcFile << "#ifndef PYTHON_NO_BOUNDS_CHECK\n";
+        if (hasPhysicalBounds(mpd.inputs)) {
+          srcFile << "// treating physical bounds\n";
+          for (const auto& i : mpd.inputs) {
+            writePhysicalBounds(srcFile, name, i);
+          }
         }
-      }
-      if (hasBounds(mpd.inputs)) {
-        srcFile << "// treating standard bounds\n";
-        for (const auto& i : mpd.inputs) {
-          writeBounds(srcFile, mpd, name, i);
+        if (hasBounds(mpd.inputs)) {
+          srcFile << "// treating standard bounds\n";
+          for (const auto& i : mpd.inputs) {
+            writeBounds(srcFile, mpd, name, i);
+          }
         }
+        srcFile << "#endif /* PYTHON_NO_BOUNDS_CHECK */\n";
       }
-      srcFile << "#endif /* PYTHON_NO_BOUNDS_CHECK */\n";
     }
     if (useQuantities(mpd)) {
       srcFile << "auto " << output.name << " = " << output.type << "{};\n";
@@ -464,17 +467,19 @@ namespace mfront {
         << "} catch(...){\n"
         << "  return throwPythonRuntimeException(\"unknown C++ exception\");\n"
         << "}\n";
-    if ((hasPhysicalBounds(mpd.output)) || (hasBounds(mpd.output))) {
-      srcFile << "#ifndef PYTHON_NO_BOUNDS_CHECK\n";
-      if (hasPhysicalBounds(mpd.output)) {
-        srcFile << "// treating physical bounds\n";
-        writePhysicalBounds(srcFile, name, mpd.output);
+    if (!areRuntimeChecksDisabled(mpd)) {
+      if ((hasPhysicalBounds(mpd.output)) || (hasBounds(mpd.output))) {
+        srcFile << "#ifndef PYTHON_NO_BOUNDS_CHECK\n";
+        if (hasPhysicalBounds(mpd.output)) {
+          srcFile << "// treating physical bounds\n";
+          writePhysicalBounds(srcFile, name, mpd.output);
+        }
+        if (hasBounds(mpd.output)) {
+          srcFile << "// treating standard bounds\n";
+          writeBounds(srcFile, mpd, name, mpd.output);
+        }
+        srcFile << "#endif /* PYTHON_NO_BOUNDS_CHECK */\n";
       }
-      if (hasBounds(mpd.output)) {
-        srcFile << "// treating standard bounds\n";
-        writeBounds(srcFile, mpd, name, mpd.output);
-      }
-      srcFile << "#endif /* PYTHON_NO_BOUNDS_CHECK */\n";
     }
     srcFile << "return Py_BuildValue(\"d\"," << output.name << ");\n"
             << "} // end of " << name << "\n\n"
